pub const fn status_class(code: u16) -> Option<StatusClass>Expand description
Returns the broad HTTP status class for a code in the standard range.
pub const fn status_class(code: u16) -> Option<StatusClass>Returns the broad HTTP status class for a code in the standard range.